summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoGuides.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:32:11 -0600
commit94844816550ad672ccfcdc25659c625546239998 (patch)
treee35fc60fd736c645d59f6408af032774ad8023d3 /lib/kofficeui/KoGuides.h
parent2a811c38c74c03648ecf857e566c44483cbad706 (diff)
downloadkoffice-94844816550ad672ccfcdc25659c625546239998.tar.gz
koffice-94844816550ad672ccfcdc25659c625546239998.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'lib/kofficeui/KoGuides.h')
-rw-r--r--lib/kofficeui/KoGuides.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/lib/kofficeui/KoGuides.h b/lib/kofficeui/KoGuides.h
index b98b0472..c1f66138 100644
--- a/lib/kofficeui/KoGuides.h
+++ b/lib/kofficeui/KoGuides.h
@@ -58,8 +58,8 @@ public:
*/
void paintGuides( TQPainter &painter );
- typedef int SnaptqStatus;
- static const SnaptqStatus SNAP_NONE, SNAP_HORIZ, SNAP_VERT, SNAP_BOTH;
+ typedef int SnapStatus;
+ static const SnapStatus SNAP_NONE, SNAP_HORIZ, SNAP_VERT, SNAP_BOTH;
/**
* @brief Handle mousePressEvent
@@ -148,17 +148,17 @@ public:
* @brief Snap rect to guidelines
*
* This looks for a guide which is in reach for the guide as defined in snap.
* This method has the abillity to combine more calls. The snaptqStatus and diff args are both input and
* output. On first call you should set snaptqStatus to 0. The return value would then show in which
* directions it has snapped. If you combine several KoGuides you can let these output arguments
* be input for the next koGuide. That way you'll always catch the nearest guide.
*
* @param rect the rect which should be snapped
* @param snap the distance within the guide should snap - but always snap if already snapped
* @param snaptqStatus if horiz,vert or both directions are snapped (both in and out param).
* @param diff distance away from guide. Only valid if status is snapping (both in and out param)
*/
- void snapToGuideLines( KoRect &rect, int snap, SnaptqStatus &snaptqStatus, KoPoint &diff );
+ void snapToGuideLines( KoRect &rect, int snap, SnapStatus &snapStatus, KoPoint &diff );
/**
* @brief Snap rect to guidelines
@@ -167,13 +167,13 @@ public:
*
* @param pos the position which should be snapped
* @param snap the distance wherein the guide should snap - but always snap if already snapped
* @param snaptqStatus if horiz,vert or both directions are snapped (both in and out param)
* @param diff distance away from guide. Only valid if status is snapping (both in and out param)
*/
- void snapToGuideLines( KoPoint &pos, int snap, SnaptqStatus &snaptqStatus, KoPoint &diff );
+ void snapToGuideLines( KoPoint &pos, int snap, SnapStatus &snapStatus, KoPoint &diff );
/**
- * @brief tqrepaint guides if any changed snapping status
+ * @brief repaint guides if any changed snapping status
*
* This issues a paint request if any guides have changed snapping status.
*
@@ -182,16 +182,16 @@ public:
void repaintSnapping( const KoRect &snappedRect );
/**
- * @brief tqrepaint guides if any changed snapping status
+ * @brief repaint guides if any changed snapping status
*
* This issues a paint request if any guides have changed snapping status.
*
* @param snappedPoint the point after it has been snapped
*/
- void repaintSnapping( const KoPoint &snappedPoint, SnaptqStatus snaptqStatus );
+ void repaintSnapping( const KoPoint &snappedPoint, SnapStatus snapStatus );
/**
- * @brief tqrepaint guides so none is snapped
+ * @brief repaint guides so none is snapped
*
* This issues a paint request if any guides have changed snapping status.
* It also effectively un-snaps all since it doesn't take an argument
@@ -253,9 +253,9 @@ signals:
/**
* @brief This signal is emitted when guides start/stop painting.
*
- * With this signal it is possible to only tqrepaint the guides in the paint
+ * With this signal it is possible to only repaint the guides in the paint
* method of the canvas. Just set/unset a flag when this signal is emmited.
- * This signal is emitted before and after a tqrepaint is done.
+ * This signal is emitted before and after a repaint is done.
*
* @param state true when starting painting guides, false when stopping.
*/
@@ -148,17 +148,17 @@ public:
*
* This looks for a guide which is in reach for the guide as defined in snap.
- * This method has the abillity to combine more calls. The snaptqStatus and diff args are both input and
- * output. On first call you should set snaptqStatus to 0. The return value would then show in which
+ * This method has the abillity to combine more calls. The snapStatus and diff args are both input and
+ * output. On first call you should set snapStatus to 0. The return value would then show in which
* directions it has snapped. If you combine several KoGuides you can let these output arguments
* be input for the next koGuide. That way you'll always catch the nearest guide.
@@ -148,17 +148,17 @@ public:
* @param rect the rect which should be snapped
* @param snap the distance within the guide should snap - but always snap if already snapped
- * @param snaptqStatus if horiz,vert or both directions are snapped (both in and out param).
+ * @param snapStatus if horiz,vert or both directions are snapped (both in and out param).
* @param diff distance away from guide. Only valid if status is snapping (both in and out param)
*/
@@ -167,13 +167,13 @@ public:
* @param pos the position which should be snapped
* @param snap the distance wherein the guide should snap - but always snap if already snapped
- * @param snaptqStatus if horiz,vert or both directions are snapped (both in and out param)
+ * @param snapStatus if horiz,vert or both directions are snapped (both in and out param)
* @param diff distance away from guide. Only valid if status is snapping (both in and out param)
*/